#
# spec file for package saphana-checks
#
# Copyright (c) 2016 SAP SE or an SAP affiliate company. All rights reserved.
# Copyright (c) 2024-2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

Name:           saphana-checks
VCS: https://src.suse.de/SLFO-pool/saphana-checks#8b998483ff3fcb4fcdd0cc2f4fd4b718ca593b010183d9e70f3ea54ac1dc8b19
Summary:        Linux OS checks for SAP HANA hosts
Version:        2503+1.g4c58f1e
Release:        160000.1.1
Group:          Productivity/Databases/Tools
License:        Apache-2.0
Autoreq:        0
BuildArch:      noarch
URL:            https://github.com/SAP/arp142-hana
Source0:        %{name}-%{version}.tar.gz
Source1:        rpmlintrc
Requires:       bash

%description
Check Linux OS configuration recommendations for SAP HANA hosts - running on SLES for Intel x64 and IBM Power

%prep
mkdir -p %{SRCDIR}
cd %{SRCDIR}
tar xf %{SOURCE0}
mv %{name}*/scripts %{name}
mkdir -p doc
cp %{name}*/LICENSE doc
cp %{name}*/README.md doc/README
cp doc/* %{name}
rm -rf %{name}/tests
rm -f %{name}/lib/*/*rhel*
rm -f %{name}/lib/*/*RHEL*

%build

%install
cd %{SRCDIR}
mkdir -p %{buildroot}/usr/lib/%{name}
cp -rp %{name}/* %{buildroot}/usr/lib/%{name}
mkdir -p %{buildroot}/%{_docdir}/%{name}
install -m 0444 doc/* %{buildroot}/%{_docdir}/%{name}

%files
%defattr(-,root,root)
%dir /usr/lib/%{name}
/usr/lib/%{name}
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/LICENSE

%changelog
* Mon Mar 31 2025 abriel@suse.com
- Update to version 2503+1.g4c58f1e:
  * GH - CI new shfmt version (#305)
  * CHECKS
  * SLES15.2 out of support - remove from all checks (#286)
  * OS kernel/Hyperscaler
  * timesync - remove systemd (RHEL6) handling (#287)
  * SUSE NFS client performance regression with filesystem
    containing large number of files (#293)
  * SLES15 - NFS getattr performance issue (#297)
  * SLES kernel issues - SUSE KB changes, SLES15.3 latest kernel
    retracted (#294)
  * Kernel issue clock_gettime @ IBM Power - replace HANA issue
    by SAP Note (#289)
  * corosync - SLES15.4 - new fixed version required (#298)
  * Azure new azcopy version (#296)
  * GPFS - new minimal versions 5.2.* and 5.1.9.* (#299)
  * SLES saptune 3.1.5 (#301)
  * GCP - new certified m4 instances (#303)
  * Azure - new certified v3 instances as of March 27th (#307)
  * Agents
  * GCP Monitor Agent - new version 3.7 (#300)
  * HANA
  * HANA infra issue - "hanging threads" HANA SPS8 affecting
    IBM Power systems only (#292)
  * SAPHanaSR-ScaleOut 0.185.4 (#302)
  * SAPHanaSR-angi 1.2.10 (#308)
  * HANA client - new version (#304)
* Fri Jan 31 2025 abriel@suse.com
- Update to version 2501+1.g53705f6:
  * HANA detection - look also into /usr/sap/sapservices/sapservices (#281)
  * CHECKS
  * new CHECK - Azure azcopy version (#278)
  * new CHECK - sssd version - BUG socket leaks (#284)
  * OS kernel/Hyperscaler
  * SLES - new 1y old kernel versions, new systemd minimal versions (#277)
  * saptune - new version 3.1.4 (#282)
  * Amazon, IBM - new instances 32TiB, 3.9-6-7.6TiB (#268)
  * Amazon - 2 new instances u7i-* (#279)
  * IBM Cloud - SLES15.6 (#272)
  * Agents
  * SAP Host Agent 7.22 PL66 (#267)
  * GCP backint agent deprecated and running out of support soon. - throw an Error and don't check version any longer (#273)
  * Amazon backint agent - new version (#275)
  * SAPHanaRA-angi - new version (#270)
  * HANA
  * HANA client - new version 2.23.26 (#285)
  Sat Nov 30 17:22:05 UTC 2024 - Peter Pitterling
- version update to v2411-1
  * new function LIB_FUNC_NORMALIZE_RPMn - using namerefs (supported since bash 4.3) (#250)
  * shellcheck - run optional tests - fix bracing, case default (#254)
  * CHECKS
  * new CHECK hana_revision_infra_issues (#241)
  * new CHECK SAPHanaSR-angi (#240)
  * new check for correct hostname setting (#252)
  * SLES15.1 - remove from checks (#243)
  * OS kernel
  * os_hana_support_intel - Azure, Amazon,GCP - SLES15.6 (#261)
  * SLES kernels - new minimal versions (<1y) (#266)
  * SLES - 1year old kernels (#237)
  * SLES - clock_gettime @ IBM Power - hanging HANA callstacks - fix last digit (#235)
  * SLES - clock_gettime @ IBM Power - hanging HANA callstacks (#231)
  * IBM Power @ IBM Cloud - add information from "2947579 - SAP HANA on IBM Power Virtual Servers" (#260)
  * HANA
  * SAP HANA SPS8 released - SLES 15.5/15.6 (#257)
  * HANA matrix - remove out of support OSses (#242)
  * HANA client - new version (#247)
  * Agents
  * SAP Host Agent 7.22 PL65 (#230)
  * IP port hostagent - product_list - check for valid entries from list (#251)
  * GCP Agent - new version (#238)
  * AWS backint agent - new version (#245)
  * sapconf - new version 15.4+ , simplify versions (#262)
  * GPFS - new recommended version (long term support) (#244)
  * UNIT TESTS
  * shunit2 - work around teardown erroneously executed twice (#259)
  * Unittest for new CHECK hana_revision_infra_issues (#246)
* Thu Nov  7 2024 abriel@suse.com
- saphana-checks tool from SAP packaged for SUSE Linux Enterprise
  Server for SAP Applications
  Will be installed in /usr/lib/saphana-checks instead of
  /opt/sap/saphana-checks
  (jsc#PED-8760, jsc#PED-8761)
  Mon Sep 30 17:22:05 UTC 2024 - Peter Pitterling
- version update to v2409-1
  * CHECKS
  * add SLES15.6 support - new OS certification
  * new 1420_cpu_idle_kvm_haltpoll_intel - KVM CPUidle haltpoll governor and module parameter
  * edit 0002_os_hana_support_sles_intel - Azure SLES15.6
  * edit 0101_supported_instances_azure - new instances 09/2024
  * edit 0104_supported_instances_gcp - new x4 instance
  * edit 0106_supported_instances_ibmcloud - IBM Cloud has introduced new instances for 08/2024
  * edit 0441_saptune_sles - new version 3.1.3
  * edit 0600_systemd_version - version containing perf fixes based on SLES Development
  * edit 1400_cpu_idle_driver_intel - CPUidle handle KVM haltpoll
  * edit 1700_irqbalance_service - remove systemd handlng (SLES11); adjust check messages
  * edit 1700_irqbalance_service - Azure = ON and new InfoText
  * edit 2000_transparent_hugepages - madvise is the new recommendation now
  * edit 5530_nfs_mount_nconnect - handle AWS correctly, extend check to handle non-supported OS
  * edit 8500_sap_hana_client - new HANA client version 2.22.27
  * edit 9100_monitor_agent_omsagent_azure - Azure omsagent deprecated as of August 31 2024
  * edit 9400_monitor_agent_sap_gcp - new version 3.5
  Wed Jul 31 11:42:35 UTC 2024 - Peter Pitterling
- version update to v2407-1
  * CHECKS
  * new 0006_os_hana_release_sles - OS-HANA-RELEASE ranges
  * new 0210_kernel_pid_max_sles - SLES15 pid_max
  * edit 0002_os_hana_support_sles_intel - OS Support adjustments for Huawei
  * edit 0102_supported_instances_amazon - new u7in instances
  * edit 0104_supported_instances_gcp - new x4 instances, new c3 instance
  * edit 1250_cpu_hyperthreading_intel - Hyperthreading for Hitachi DS9160 (Sapphire Rapids)
  * edit 1260_cpu_smthreading_ibmpower - IBM Power SMT mode - fix output in case of non-range
  * edit 2305_vm_memory_failure_kill - change SAP Note
  * edit 5530_nfs_mount_nconnect - nconnect, Netapp recommends usrsap|shared =4 for onprem, maintain for AWS separately
  * edit 7018_pacemaker_attributes - make check more robust (is pacemaker active, are attributes really processed)
  * edit 7020_ha_resource_agents_sles - new versions
  * edit 8500_sap_hana_client - new HANA client version 2.21.28
  * edit 9100_monitor_agent_omsagent_azure - new version 1.19
  * remove 3312_ena_version_amazon - driver versions no longer maintained
  Fri May 31 21:52:47 UTC 2024 - Peter Pitterling
- version update to v2405-1
  * CHECKS
  * edit 0000_os_support_sles - refactor for easier modifications, add unit tests
  * edit 0010_os_kernel_sles - new minimal versions
  * edit 0011_os_kernel_knownissue_sles - Azure Linux OS Crash for VMs using Accelerated Networking
  * edit 0011_os_kernel_knownissue_sles - SLES12.5 latest kernel retracted due to NFS issues
  * edit 0300_timer_and_clocksource_intel - allow non-tsc as recommended
  * edit 0440_sapconf_sles - new versions, add links to packages
  * edit 0441_saptune_sles - new versions, add links to packages
  * edit 0800_sap_host_agent - SAP Host Agent 7.22 PL64
  * edit 0811_uuidd_version - SLES new version containing fixes for perf regressions
  * edit 1250_cpu_hyperthreading_intel - Hyperthreading for BullSequana SH160 (Sapphire Rapids)
  * edit 3012_network_parameter_defaults - add tcp_adv_win_scale, minor cleanup
  * edit 3304_network_interface_gvnic_gcp - check gvnic only for VMs not bare metal instances
  * edit 3304_network_interface_gvnic_gcp - GCP network driver for gvnic is 'gve'
  * edit 8500_sap_hana_client - new HANA client version 2.20.23
  * edit 9400_monitor_agent_sap_gcp - new version 3.3
  Sun Apr 28 10:42:47 UTC 2024 - Peter Pitterling
- version update to v2403-1
  * CHECKS
  * new 5522_nfs_mount_rwsize_amazon - nfs mount option rwsize amazon
  * new 5530_nfs_mount_nconnect - nfs mount option nconnect for HANA data,log,shared and /usr/sap
  * new 7015_pacemaker_version - pacemaker version
  * new 7018_pacemaker_attributes - pacemaker_attributes (resource-stickiness,migration-threshold)
  * edit 0011_os_kernel_knownissue_sles - SLES 15.4 clocksource / SLES12.5 PMEM blocking savepoint
  * edit 0104_supported_instances_gcp - new certified instances
  * edit 0440_sapconf_sles - SLES15 new version
  * edit 0800_sap_host_agent - SAP Host Agent 7.22 PL63
  * edit 0811_uuidd_version - note is clearly stating if coming from SAP,SUSE,Red Hat, new version SLES15.2
  * edit 1200_shared_processor_mode_ibmpower - fix BUG - DEDICATED! - wrong comparison
  * edit 2600_vm_dentry_unused - add Red Hat solution, refactor
  * edit 4500_ibm-gpfs-_version_intel - update to latest available/recommended 5.1.x kernels
  * edit 5505_nfsv4_max_session_slots - NFS client v4: increase max session slots; add link for amazon
  * edit 5010_io_scheduler_blockdevices - include nvme devices and also dm_multipath devices, fix SAP Notes
  * edit 5521_nfs_mount_rwsize_azure - harmonize with new 5522
  * edit 7020_ha_resource_agents_sles - new SAPHanaSR (fix the hexdump log for empty node states)
  * edit 8500_sap_hana_client - new HANA client version 2.20.15
  * edit 9101_monitor_agent_dependency_azure - new version
  * edit 9400_monitor_agent_sapdataprovider_amazon - new SAP note
  * edit 9400_monitor_agent_sap_gcp - new version
